@@ -225,19 +225,14 @@ gboolean update_minutes(gpointer data)
   locTime=localtime(&curTime);
   if ((locTime->tm_min!=statusbar_plugin->previous)||(statusbar_plugin->updated))
   {
-    cookie_t *list,*iter;
-
     statusbar_plugin->curColour=statusbar_plugin->fontColour;
     if (statusbar_plugin->alarms)
     {
+    	cookie_t *list,*iter;
+    	
 		list = alarm_event_query(curTime, curTime + statusbar_plugin->alarm2Time*60*60, 0, 0);
-		if (list == NULL) {
-			/*hildon_banner_show_information(NULL,NULL,"alarm_event_query() failed");*/
-		}
-	  
-		else if (list[0] == (cookie_t) 0) {
-
-		} else {
+		if ((list != NULL) && (list[0] != (cookie_t) 0))
+		{
 			for (iter = list; *iter != (cookie_t) 0; iter++) {
 				alarm_event_t* alarm=alarm_event_get(*iter);
 				if (g_strcasecmp(alarm->icon,ICON_FILE)==0)
@@ -250,12 +245,8 @@ gboolean update_minutes(gpointer data)
 		}
 
 		list = alarm_event_query(curTime, curTime + statusbar_plugin->alarm1Time*60*60, 0, 0);
-		if (list == NULL) {
-			/*hildon_banner_show_information(NULL,NULL,"alarm_event_query() failed");*/
-		}
-		else if (list[0] == (cookie_t) 0) {
-			
-		} else {
+		if ((list != NULL) && (list[0] == (cookie_t) 0))
+		{
 			for (iter = list; *iter != (cookie_t) 0; iter++) {
 				alarm_event_t* alarm=alarm_event_get(*iter);
 				if (g_strcasecmp(alarm->icon,ICON_FILE)==0)
@@ -280,16 +271,10 @@ gboolean update_minutes(gpointer data)
 			      DBUS_TYPE_BOOLEAN,statusbar_plugin->stacked,
 			      DBUS_TYPE_INVALID);
 			      
-	if (ret!=OSSO_OK)
+	if (statusbar_plugin->ampm)
 	{
-		timeString[0]="A";
-	}
-	else
-	{
-		if (statusbar_plugin->ampm)
-		{
-		  if (statusbar_plugin->stacked)
-		  {
+	  if (statusbar_plugin->stacked)
+	  {
 		if (locTime->tm_hour<12)
 		{
 		  strftime(timeString,45,"<span size='small'>%M\nAM</span>",locTime);
@@ -298,9 +283,9 @@ gboolean update_minutes(gpointer data)
 		{
 		  strftime(timeString,45,"<span size='small'>%M\nPM</span>",locTime);
 		}
-		  }
-		  else
-		  {
+	  }
+	  else
+	  {
 		if (locTime->tm_hour<12)
 		{
 		  strftime(timeString,45,"%M<span size='xx-small'>A</span>",locTime);
@@ -309,13 +294,13 @@ gboolean update_minutes(gpointer data)
 		{
 		  strftime(timeString,45,"%M<span size='xx-small'>P</span>",locTime);
 		}
-		  }
-		}
-		else
-		{
-		  strftime(timeString,45,"%M",locTime);
-		}
+	  }
 	}
+	else
+	{
+	  strftime(timeString,45,"%M",locTime);
+	}
+
     gtk_label_set_markup(GTK_LABEL(statusbar_plugin->minutesLabel),g_strconcat("<span foreground='#",statusbar_plugin->curColour,"' font-desc='",statusbar_plugin->fontDesc,"'>",timeString,"</span>",NULL));
 
   }
